@@ -18,15 +18,17 @@ require 5;
 use Socket;
 use Symbol;
 use Carp;
+
+# NOTE - you may have to 'use IO::Socket::INET' if yer perl install
+#	is cracked...
 use IO::Socket;
+
+# Fancy pants array stuff
 use JavaArray;
 
 # Now allow '==' to mimic 'same' functionality
 use overload '==' => "same", 'fallback' => 1;
 
-# NOTE - you may have to 'use IO::Socket::INET' if yer perl install
-#	is cracked...
-
 use vars qw ($AUTOLOAD @ISA);
 
 require Exporter;
@@ -285,7 +287,7 @@ sub send_line
 	my($self,$line) = @_;
 	return if (!$self || !$line);
 #print STDERR "SENDING -$line-\n";
-	$self->get_socket->print("$line\n");
+	$self->get_socket->print("$line\n\n");
 }
 	
 sub send_command_and_get_response
@@ -294,15 +296,25 @@ sub send_command_and_get_response
 	my $resp = "";
 	if ($self->send_line($line))
 	{
-		$resp = $self->get_socket->getline;
-		if (!defined $resp)
+		# The response ends w/a  on a line by itself
+		while (1)
 		{
-			croak("Error receiving response");
+			my $line;
+			$line = $self->get_socket->getline;
+			if (!defined $line)
+			{
+				croak("Error receiving response");
+			}
+			$line =~ s/\r//g;	# clean up input from Winblows
+
+			# Check for end of response
+			last if ($line =~ /^$/);
+
+			$resp .= $line;
 		}
-		chomp $resp;
-		$resp =~ s/\r//g;	# clean up input from Winblows
+
+		chomp $resp;	# clean up last newline
 
-		# Should prolly do something more interesting here
 		croak($resp) if ($resp =~ /^ERROR/);
 
 		return $resp;
@@ -506,30 +518,27 @@ sub DESTROY
 sub AUTOLOAD
 {
 	my($self,@args) = @_;
-	local($") = PARAMETER_SEPARATOR;
 	my ($func) = $Java::AUTOLOAD =~ /::(.+)$/;
-	my $obj;
+	my @goo;
 
-	if ($func =~ /_/)
+	# it's a static call UNLESS $self is an instantiated class
+	if ($func =~ /_/ && !$self->{java})
 	{
-		# it's a static call
 		# called like $java->java_lang_Class("forName","java.lang.String");
+		# Pull out object name
+		my $obj;
 		($obj = $func) =~ s/_/\./g;
-		$func = shift @args;
-		
+		push @goo, $obj;
 	}
 	else
 	{
 		# regular method call
 		# called like $frame->setSize(200,200);
-		$obj = $self->{name};
+		# Pull out object name & function name
+		push @goo, $self->{name}, $func;
 	}
 
-	# Make args java-friendly
-	@args = pretty_args(@args);
-		
-	my $resp=$self->send_command_and_get_response("CAL $obj%$func(@args)");
-	return $self->new_java_object($resp);
+	return base_call($self,@goo,@args);
 }
 
 #
@@ -539,6 +548,18 @@ sub AUTOLOAD
 # $java->static_call("MyStaticClass","function_name","param1","param2"....);
 #
 sub static_call
+{
+	return base_call(@_);
+}
+
+# wrapper routine for instantiated calls
+sub call
+{
+	my $self = shift;
+	return base_call($self,$self->{name},@_);
+}
+
+sub base_call
 {
 	my($self,$obj,$func,@args) = @_;
 	local($") = PARAMETER_SEPARATOR;
@@ -779,7 +800,12 @@ For example:
 	$frame->show();  (or $frame->show)
 
 Note functions that don't take any parameters don't need the parentheses!
+Alternatively you can use the 'call' function to make method calls:
 
+	$frame->call('setSize', 500,500);
+	$frame->call('show');
+
+But that's no fun!
 	
 To call static functions the syntax is slightly different.
 
@@ -1112,7 +1138,7 @@ fully-qualified java object or primitive name and a dimension.
         All array references will be _references_ to these objects.  
         Here's how it looks (compare with 'old style' below):
 
-	# This will create a char array with 100 elements
+	# This will create a String array with 100 elements
         #       (this is the same)
 	my $array  = $java->create_array("java.lang.String",100);
 
